@@ -1,6 +1,6 @@
 /*
-  The oSIP library implements the Session Initiation Protocol (SIP -rfc2543-)
-  Copyright (C) 2001  Aymeric MOIZARD jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001,2002,2003,2004  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -23,10 +23,17 @@
 #ifndef _INTERNAL_H_
 #define _INTERNAL_H_
 
+#ifdef __BORLANDC__
+#define _timeb timeb
+#define _ftime ftime
+#endif
+
+#ifndef DOXYGEN
+
 /**
  * Structure for payload management. Each payload element
  * represents one codec of a media line.
- * @defvar __payload_t
+ * @var __payload_t
  */
 typedef struct __payload __payload_t;
 
@@ -82,7 +89,7 @@ typedef pthread_mutex_t osip_mutex_t;
 #endif
 
 #ifdef __VXWORKS_OS__
-typedef
+typedef struct
 {
   int id;
 }
@@ -167,7 +174,7 @@ typedef sem_t osip_sem_t;
 #endif
 /**
  * Structure for referencing a semaphore element.
- * @defvar osip_sem_t
+ * @var osip_sem_t
  */
 typedef sem_t osip_sem_t;
 
@@ -188,13 +195,17 @@ osip_sem_t;
 
 #if defined(__PSOS__) || defined(__VXWORKS_OS__)
 
-/* TODO */
+typedef struct osip_cond
+{
+  struct osip_sem *sem;
+} osip_cond_t;
+
 
 #else
 
 /**
  * Structure for referencing a condition variable element.
- * @defvar struct osip_cond
+ * @var osip_cond_t
  */
 #if defined(HAVE_PTHREAD) || defined(HAVE_PTH_PTHREAD_H)
 typedef struct osip_cond
@@ -217,3 +228,5 @@ typedef struct osip_cond
 #endif
 
 #endif
+
+#endif
