@@ -1,19 +1,19 @@
 /*
-  eXosip - This is the eXtended osip library.
-  Copyright (C) 2002, 2003  Aymeric MOIZARD  - jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001,2002,2003,2004  Aymeric MOIZARD jack@atosc.org
   
-  eXosip is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Lesser General Public
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
   
-  eXosip is distributed in the hope that it will be useful,
+  This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Lesser General Public License for more details.
   
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
+  You should have received a copy of the GNU Lesser General Public
+  License along with this library; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
@@ -38,7 +38,7 @@
 
 /**
  * @defgroup oSIP_COND oSIP condition variables definitions
- * @ingroup oSIP
+ * @ingroup osip2_port
  * @{
  */
 
@@ -47,7 +47,7 @@ extern "C"
 {
 #endif
 
-#if defined(__PSOS__) || defined(__VXWORKS_OS__)
+#if defined(__PSOS__)
 
 /* TODO */
 
@@ -58,7 +58,7 @@ extern "C"
 #if defined(WIN32) || defined(_WIN32_WCE)
 /**
  * timespec structure
- * @defvar struct timespec
+ * @struct timespec
  */
   struct timespec
   {
@@ -69,15 +69,15 @@ extern "C"
 
   struct osip_cond;
 
-/*
+/**
  * Allocate and Initialise a condition variable
  */
   struct osip_cond *osip_cond_init (void);
-/*
+/**
  * Destroy a condition variable
  * @param cond The condition variable to destroy.
  */
-  int osip_cond_destroy (struct osip_cond *_cond);
+  int osip_cond_destroy (struct osip_cond *cond);
 /**
  * Signal the condition variable.
  * @param cond The condition variable to signal.
