@@ -1,6 +1,6 @@
 /*
-  The oSIP library implements the Session Initiation Protocol (SIP -rfc2543-)
-  Copyright (C) 2001  Aymeric MOIZARD jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001,2002,2003,2004  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -31,7 +31,7 @@
 
 /**
  * @defgroup oSIP_PARSER oSIP parser Handling
- * @ingroup oSIP
+ * @ingroup osip2_parser
  * @{
  */
 
@@ -149,6 +149,20 @@ extern "C"
  */
   int osip_message_get_allow (const osip_message_t * sip, int pos,
 			      osip_allow_t ** dest);
+/**
+ * Set the Authentication-info header.
+ * @param sip The element to work on.
+ * @param hvalue The string describing the element.
+ */
+  int osip_message_set_authentication_info (osip_message_t * sip, const char *hvalue);
+/**
+ * Get one Authentication-info header.
+ * @param sip The element to work on.
+ * @param pos The index of the element to get.
+ * @param dest A pointer on the header found.
+ */
+  int osip_message_get_authentication_info (const osip_message_t * sip, int pos,
+			       osip_authentication_info_t ** dest);
 /**
  * Set the Authorization header.
  * @param sip The element to work on.
@@ -343,6 +357,22 @@ extern "C"
 					    int pos,
 					    osip_proxy_authorization_t **
 					    dest);
+/**
+ * Set the Proxy-authentication-info header.
+ * @param sip The element to work on.
+ * @param hvalue The string describing the element.
+ */
+  int osip_message_set_proxy_authentication_info (osip_message_t * sip,
+					  const char *hvalue);
+/**
+ * Get the Proxy-authentication-info header.
+ * @param sip The element to work on.
+ * @param pos The index of the element to get.
+ * @param dest A pointer on the header found.
+ */
+  int osip_message_get_proxy_authentication_info (const osip_message_t * sip,
+				      int pos,
+				      osip_proxy_authentication_info_t ** dest);
 /**
  * Set the Record-Route header.
  * @param sip The element to work on.
@@ -458,15 +488,17 @@ extern "C"
 /**
  * Set the Body of the SIP message.
  * @param sip The element to work on.
- * @param buf The string containing the body.
+ * @param buf The buffer containing the body.
+ * @param length The length of the buffer.
  */
-  int osip_message_set_body (osip_message_t * sip, const char *buf);
+  int osip_message_set_body (osip_message_t * sip, const char *buf, size_t length);
 /**
- * Set a type for a body. (NOT TESTED! use with care)
+ * Set the Body of the SIP message. (please report bugs)
  * @param sip The element to work on.
- * @param buf the mime type of body.
+ * @param buf the buffer containing the body.
+ * @param length The length of the buffer.
  */
-  int osip_message_set_body_mime (osip_message_t * sip, const char *buf);
+  int osip_message_set_body_mime (osip_message_t * sip, const char *buf, size_t length);
 /**
  * Get one body header.
  * @param sip The element to work on.
