@@ -1,6 +1,6 @@
 /*
-  The oSIP library implements the Session Initiation Protocol (SIP -rfc2543-)
-  Copyright (C) 2001  Aymeric MOIZARD jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001,2002,2003,2004  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -147,15 +147,31 @@ extern "C"
 
 #ifndef WIN32
 
+typedef void *osip_malloc_func_t(size_t size);
+typedef void osip_free_func_t(void *ptr);
+typedef void *osip_realloc_func_t(void *ptr, size_t size);
+
+extern osip_malloc_func_t  *osip_malloc_func;
+extern osip_realloc_func_t *osip_realloc_func;
+extern osip_free_func_t    *osip_free_func;
+
+void osip_set_allocators(osip_malloc_func_t  *malloc_func, 
+                         osip_realloc_func_t *realloc_func, 
+                         osip_free_func_t    *free_func);
+
 #ifndef osip_malloc
-#define osip_malloc(S) malloc(S)
+#define osip_malloc(S) (osip_malloc_func?osip_malloc_func(S):malloc(S))
+#endif
+#ifndef osip_realloc
+#define osip_realloc(P,S) (osip_realloc_func?osip_realloc_func(P,S):realloc(P,S))
 #endif
 #ifndef osip_free
-#define osip_free(P) { if (P!=NULL) free(P); }
+#define osip_free(P) { if (P!=NULL) { if (osip_free_func) osip_free_func(P); else free(P);} }
 #endif
 
 #else
 void *osip_malloc(size_t size);
+void *osip_realloc(void *, size_t size);
 void osip_free(void *);
 #endif
 
@@ -228,10 +244,15 @@ void osip_free(void *);
   }
   osip_trace_level_t;
 
+
+typedef void osip_trace_func_t(char *fi, int li, osip_trace_level_t level, char *chfr, va_list ap);
+
 /* these are defined in all cases, but are empty when oSIP is compiled
    without trace */
+  void osip_trace_initialize_func (osip_trace_level_t level, osip_trace_func_t *func);
   void osip_trace_initialize_syslog (osip_trace_level_t level, char *ident);
   void osip_trace_initialize (osip_trace_level_t level, FILE * file);
+  void osip_trace_enable_until_level (osip_trace_level_t level);
   void osip_trace_enable_level (osip_trace_level_t level);
   void osip_trace_disable_level (osip_trace_level_t level);
   int osip_is_trace_level_activate (osip_trace_level_t level);
