@@ -25,6 +25,8 @@
 
 #include "xixt.h"
 
+#ifndef DOXYGEN
+
 void add_gettimeofday (struct timeval *atv, int ms);
 void min_timercmp (struct timeval *tv1, struct timeval *tv2);
 #ifdef WIN32
@@ -51,11 +53,6 @@ osip_event_t *__osip_event_new (type_t type, int transactionid);
 type_t evt_set_type_incoming_sipmessage (osip_message_t * sip);
 type_t evt_set_type_outgoing_sipmessage (osip_message_t * sip);
 
-/* send a request on UDP.                       */
-int udp_send_request (osip_message_t * request, osip_uri_t * proxy);
-
-/* send a response on UDP.                       */
-int udp_send_response (osip_message_t * response);
 
 void __ict_load_fsm (void);
 void __ist_load_fsm (void);
@@ -192,3 +189,5 @@ __osip_transaction_matching_request_osip_to_xist_17_2_3 (osip_transaction_t *
 							 request);
 
 #endif
+
+#endif
