@@ -30,15 +30,12 @@ static struct osip_mutex *nict_fastmutex;
 static struct osip_mutex *nist_fastmutex;
 #endif
 
-#ifdef OSIP_RETRANSMIT_2XX
 
 #include <osip2/osip_dialog.h>
 #ifdef OSIP_MT
 static struct osip_mutex *ixt_fastmutex;
 #endif
 
-#endif
-
 static int __osip_global_init (void);
 static void __osip_global_free (void);
 static int increase_ref_count (void);
@@ -62,9 +59,7 @@ __osip_global_init ()
   nict_fastmutex = osip_mutex_init ();
   nist_fastmutex = osip_mutex_init ();
 
-#ifdef OSIP_RETRANSMIT_2XX
   ixt_fastmutex = osip_mutex_init ();
-#endif
 
 #endif
   return 0;
@@ -84,13 +79,59 @@ __osip_global_free ()
   osip_mutex_destroy (nict_fastmutex);
   osip_mutex_destroy (nist_fastmutex);
 
-#ifdef OSIP_RETRANSMIT_2XX
   osip_mutex_destroy (ixt_fastmutex);
 #endif
-#endif
 }
 
-#ifdef OSIP_RETRANSMIT_2XX
+void
+osip_response_get_destination (osip_message_t * response, char **address,
+			  int *portnum)
+{
+  osip_via_t *via;
+  char *host = NULL;
+  int port = 0;
+
+  via = (osip_via_t *) osip_list_get (response->vias, 0);
+  if (via)
+    {
+      osip_generic_param_t *maddr;
+      osip_generic_param_t *received;
+      osip_generic_param_t *rport;
+      osip_via_param_get_byname (via, "maddr", &maddr);
+      osip_via_param_get_byname (via, "received", &received);
+      osip_via_param_get_byname (via, "rport", &rport);
+      /* 1: user should not use the provided information
+         (host and port) if they are using a reliable
+         transport. Instead, they should use the already
+         open socket attached to this transaction. */
+      /* 2: check maddr and multicast usage */
+      if (maddr != NULL)
+	host = maddr->gvalue;
+      /* we should check if this is a multicast address and use
+         set the "ttl" in this case. (this must be done in the
+         UDP message (not at the SIP layer) */
+      else if (received != NULL)
+	host = received->gvalue;
+      else
+	host = via->host;
+
+      if (rport == NULL || rport->gvalue == NULL)
+	{
+	  if (via->port != NULL)
+	    port = osip_atoi (via->port);
+	  else
+	    port = 5060;
+	}
+      else
+	port = osip_atoi (rport->gvalue);
+    }
+  *portnum = port;
+  if (host != NULL)
+    *address = osip_strdup (host);
+  else
+    *address = NULL;
+}
+
 
 int
 osip_ixt_lock (osip_t * osip)
@@ -143,57 +184,6 @@ osip_remove_ixt (osip_t * osip, ixt_t * ixt)
   osip_ixt_unlock (osip);
 }
 
-
-void
-response_get_destination (osip_message_t * response, char **address,
-			  int *portnum)
-{
-  osip_via_t *via;
-  char *host = NULL;
-  int port = 0;
-
-  via = (osip_via_t *) osip_list_get (response->vias, 0);
-  if (via)
-    {
-      osip_generic_param_t *maddr;
-      osip_generic_param_t *received;
-      osip_generic_param_t *rport;
-      osip_via_param_get_byname (via, "maddr", &maddr);
-      osip_via_param_get_byname (via, "received", &received);
-      osip_via_param_get_byname (via, "rport", &rport);
-      /* 1: user should not use the provided information
-         (host and port) if they are using a reliable
-         transport. Instead, they should use the already
-         open socket attached to this transaction. */
-      /* 2: check maddr and multicast usage */
-      if (maddr != NULL)
-	host = maddr->gvalue;
-      /* we should check if this is a multicast address and use
-         set the "ttl" in this case. (this must be done in the
-         UDP message (not at the SIP layer) */
-      else if (received != NULL)
-	host = received->gvalue;
-      else
-	host = via->host;
-
-      if (rport == NULL || rport->gvalue == NULL)
-	{
-	  if (via->port != NULL)
-	    port = osip_atoi (via->port);
-	  else
-	    port = 5060;
-	}
-      else
-	port = osip_atoi (rport->gvalue);
-    }
-  *portnum = port;
-  if (host != NULL)
-    *address = osip_strdup (host);
-  else
-    *address = NULL;
-}
-
-
 int
 ixt_init (ixt_t ** ixt)
 {
@@ -231,7 +221,7 @@ osip_start_200ok_retransmissions (osip_t * osip, osip_dialog_t * dialog,
   ixt->dialog = dialog;
   osip_message_clone (msg200ok, &ixt->msg2xx);
   ixt->sock = sock;
-  response_get_destination (msg200ok, &ixt->dest, &ixt->port);
+  osip_response_get_destination (msg200ok, &ixt->dest, &ixt->port);
   osip_add_ixt (osip, ixt);
 }
 
@@ -254,9 +244,10 @@ osip_start_ack_retransmissions (osip_t * osip, osip_dialog_t * dialog,
 }
 
 /* we stop the 200ok when receiving the corresponding ack */
-void
+struct osip_dialog *
 osip_stop_200ok_retransmissions (osip_t * osip, osip_message_t * ack)
 {
+  osip_dialog_t *dialog = NULL;
   int i;
   ixt_t *ixt;
   osip_ixt_lock (osip);
@@ -267,10 +258,12 @@ osip_stop_200ok_retransmissions (osip_t * osip, osip_message_t * ack)
 	{
 	  osip_list_remove (osip->ixt_retransmissions, i);
 	  ixt_free (ixt);
+	  dialog = ixt->dialog;
 	  break;
 	}
     }
   osip_ixt_unlock (osip);
+  return dialog;
 }
 
 /* when a dialog is destroyed by the application,
@@ -334,8 +327,6 @@ osip_retransmissions_execute (osip_t * osip)
   osip_ixt_unlock (osip);
 }
 
-#endif
-
 int
 osip_ict_lock (osip_t * osip)
 {
@@ -605,7 +596,7 @@ __osip_remove_nist_transaction (osip_t * osip, osip_transaction_t * nist)
    any call to this method should be replace this way:
 
    //osip_distribute(osip, evt);
-   osip_transaction_t *transaction = osip_find_transaction_and_add_event(osip, evt);
+   int i = osip_find_transaction_and_add_event(osip, evt);
 
    if (i!=0) // in case it's a new request
      {
@@ -1059,13 +1050,9 @@ osip_init (osip_t ** osip)
     (osip_list_t *) osip_malloc (sizeof (osip_list_t));
   osip_list_init ((*osip)->osip_nist_transactions);
 
-#ifdef OSIP_RETRANSMIT_2XX
   (*osip)->ixt_retransmissions =
     (osip_list_t *) osip_malloc (sizeof (osip_list_t));
   osip_list_init ((*osip)->ixt_retransmissions);
-#else
-  (*osip)->ixt_retransmissions = NULL;
-#endif
 
   return 0;
 }
@@ -1078,9 +1065,7 @@ osip_release (osip_t * osip)
   osip_free (osip->osip_nict_transactions);
   osip_free (osip->osip_nist_transactions);
 
-#ifdef OSIP_RETRANSMIT_2XX
   osip_free (osip->ixt_retransmissions);
-#endif
 
   osip_free (osip);
   decrease_ref_count ();
@@ -1270,6 +1255,7 @@ osip_timers_gettimeout (osip_t * osip, struct timeval *lower_tv)
   osip_mutex_lock (ist_fastmutex);
 #endif
   /* handle ist timers */
+  pos = 0;
   while (!osip_list_eol (osip->osip_ist_transactions, pos))
     {
       tr =
@@ -1301,6 +1287,7 @@ osip_timers_gettimeout (osip_t * osip, struct timeval *lower_tv)
   osip_mutex_lock (nict_fastmutex);
 #endif
   /* handle nict timers */
+  pos = 0;
   while (!osip_list_eol (osip->osip_nict_transactions, pos))
     {
       tr =
@@ -1332,6 +1319,7 @@ osip_timers_gettimeout (osip_t * osip, struct timeval *lower_tv)
   osip_mutex_lock (nist_fastmutex);
 #endif
   /* handle nist timers */
+  pos = 0;
   while (!osip_list_eol (osip->osip_nist_transactions, pos))
     {
       tr =
@@ -1355,6 +1343,25 @@ osip_timers_gettimeout (osip_t * osip, struct timeval *lower_tv)
   osip_mutex_unlock (nist_fastmutex);
 #endif
 
+#ifdef OSIP_MT
+  osip_mutex_lock(ixt_fastmutex);
+#endif
+ {
+   ixt_t *ixt;
+   for (pos = 0; (ixt = (ixt_t *) osip_list_get(osip->ixt_retransmissions,
+						pos))!=NULL; ++pos)
+     {
+       struct timeval cmpTime;
+       div_t dValue = div(ixt->interval, 1000);
+       cmpTime.tv_sec = ixt->start + dValue.quot;
+       cmpTime.tv_usec = dValue.rem * 1000;
+       min_timercmp(lower_tv, &cmpTime);
+     }
+ }
+#ifdef OSIP_MT
+  osip_mutex_unlock (ixt_fastmutex);
+#endif
+  
   lower_tv->tv_sec = lower_tv->tv_sec - now.tv_sec;
   lower_tv->tv_usec = lower_tv->tv_usec - now.tv_usec;
 
