@@ -217,7 +217,7 @@ osip_sem_trywait (struct osip_sem *_sem)
 struct osip_mutex *
 osip_mutex_init ()
 {
-  return (struct osip_mutex *) semMCreate (0);
+  return (struct osip_mutex *) semMCreate (SEM_Q_FIFO|SEM_DELETE_SAFE);
 }
 
 void
@@ -232,7 +232,7 @@ osip_mutex_destroy (struct osip_mutex *_mut)
 int
 osip_mutex_lock (struct osip_mutex *_mut)
 {
-  osip_mutex_t *mut = (osip_mutex_t *) mut;
+  osip_mutex_t *mut = (osip_mutex_t *) _mut;
   if (mut == NULL)
     return -1;
   return semTake (mut, WAIT_FOREVER);
