@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -199,7 +199,7 @@ osip_content_type_to_str (const osip_content_type_t * content_type,
 	  + strlen (u_param->gvalue);
 	if (len < tmp_len)
 	  {
-	    buf = realloc (buf, tmp_len);
+	    buf = osip_realloc (buf, tmp_len);
 	    len = tmp_len;
 	    tmp = buf + strlen (buf);
 	  }
