@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -43,7 +43,7 @@ osip_message_init (osip_message_t ** sip)
 #endif
   *sip = (osip_message_t *) osip_malloc (sizeof (osip_message_t));
 #ifdef MEMORY_LEAKS
-  osip_trace (__FILE__, __LINE__, TRACE_LEVEL0, stdout,
+  osip_trace (__FILE__, __LINE__, TRACE_LEVEL0, NULL,
 	      "<msg_write.c> osip_message_init() = %i, malloc-free = %i, address = %x\n",
 	      comptr, freesipcptr, *sip);
   fflush (stdout);
@@ -68,6 +68,8 @@ osip_message_init (osip_message_t ** sip)
   osip_list_init ((*sip)->alert_infos);
   (*sip)->allows = (osip_list_t *) osip_malloc (sizeof (osip_list_t));
   osip_list_init ((*sip)->allows);
+  (*sip)->authentication_infos = (osip_list_t *) osip_malloc (sizeof (osip_list_t));
+  osip_list_init ((*sip)->authentication_infos);
   (*sip)->authorizations = (osip_list_t *) osip_malloc (sizeof (osip_list_t));
   osip_list_init ((*sip)->authorizations);
   (*sip)->call_id = NULL;
@@ -92,6 +94,9 @@ osip_message_init (osip_message_t ** sip)
   (*sip)->proxy_authenticates =
     (osip_list_t *) osip_malloc (sizeof (osip_list_t));
   osip_list_init ((*sip)->proxy_authenticates);
+  (*sip)->proxy_authentication_infos =
+	(osip_list_t *) osip_malloc (sizeof (osip_list_t));
+  osip_list_init ((*sip)->proxy_authentication_infos);
   (*sip)->proxy_authorizations =
     (osip_list_t *) osip_malloc (sizeof (osip_list_t));
   osip_list_init ((*sip)->proxy_authorizations);
@@ -114,6 +119,9 @@ osip_message_init (osip_message_t ** sip)
 
   (*sip)->message_property = 3;
   (*sip)->message = NULL;	/* buffer to avoid calling osip_message_to_str many times (for retransmission) */
+  (*sip)->message_length = 0;
+
+  (*sip)->application_data = NULL;
   return 0;			/* ok */
 }
 
@@ -160,7 +168,7 @@ osip_message_free (osip_message_t * sip)
     return;
   comptr--;
   freesipcptr--;
-  osip_trace (__FILE__, __LINE__, TRACE_LEVEL0, stdout,
+  osip_trace (__FILE__, __LINE__, TRACE_LEVEL0, NULL,
 	      "<msg_write.c> osip_message_free() = %i, malloc-free = %i, address = %x\n",
 	      comptr, freesipcptr, sip);
 #endif
@@ -235,6 +243,17 @@ osip_message_free (osip_message_t * sip)
       }
     osip_free (sip->allows);
   }
+  {
+    osip_authentication_info_t *al;
+
+    while (!osip_list_eol (sip->authentication_infos, pos))
+      {
+	al = (osip_authentication_info_t *) osip_list_get (sip->authentication_infos, pos);
+	osip_list_remove (sip->authentication_infos, pos);
+	osip_authentication_info_free (al);
+      }
+    osip_free (sip->authentication_infos);
+  }
   {
     osip_authorization_t *al;
 
@@ -332,6 +351,17 @@ osip_message_free (osip_message_t * sip)
       }
     osip_free (sip->proxy_authenticates);
   }
+  {
+    osip_proxy_authentication_info_t *al;
+
+    while (!osip_list_eol (sip->proxy_authentication_infos, pos))
+      {
+	al = (osip_proxy_authentication_info_t *) osip_list_get (sip->proxy_authentication_infos, pos);
+	osip_list_remove (sip->proxy_authentication_infos, pos);
+	osip_proxy_authentication_info_free (al);
+      }
+    osip_free (sip->proxy_authentication_infos);
+  }
   {
     osip_proxy_authorization_t *proxy_authorization;
 
@@ -532,6 +562,22 @@ osip_message_clone (const osip_message_t * sip, osip_message_t ** dest)
 	pos++;
       }
   }
+  {
+    osip_authentication_info_t *authentication_info;
+    osip_authentication_info_t *authentication_info2;
+
+    pos = 0;
+    while (!osip_list_eol (sip->authentication_infos, pos))
+      {
+	authentication_info =
+	  (osip_authentication_info_t *) osip_list_get (sip->authentication_infos, pos);
+	i = osip_authentication_info_clone (authentication_info, &authentication_info2);
+	if (i != 0)
+	  goto mc_error1;
+	osip_list_add (copy->authentication_infos, authentication_info2, -1);
+	pos++;
+      }
+  }
   {
     osip_authorization_t *authorization;
     osip_authorization_t *authorization2;
@@ -670,6 +716,23 @@ osip_message_clone (const osip_message_t * sip, osip_message_t ** dest)
 	pos++;
       }
   }
+  {
+    osip_proxy_authentication_info_t *proxy_authentication_info;
+    osip_proxy_authentication_info_t *proxy_authentication_info2;
+
+    pos = 0;
+    while (!osip_list_eol (sip->proxy_authentication_infos, pos))
+      {
+	proxy_authentication_info =
+	  (osip_proxy_authentication_info_t *) osip_list_get (sip->proxy_authentication_infos, pos);
+	i =
+	  osip_proxy_authentication_info_clone (proxy_authentication_info, &proxy_authentication_info2);
+	if (i != 0)
+	  goto mc_error1;
+	osip_list_add (copy->proxy_authentication_infos, proxy_authentication_info2, -1);
+	pos++;
+      }
+  }
   {
     osip_proxy_authorization_t *proxy_authorization;
     osip_proxy_authorization_t *proxy_authorization2;
@@ -793,6 +856,7 @@ osip_message_clone (const osip_message_t * sip, osip_message_t ** dest)
       }
   }
 
+  copy->message_length = sip->message_length;
   copy->message = osip_strdup (sip->message);
   copy->message_property = sip->message_property;
 
