@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -33,11 +33,8 @@ static int msg_headers_parse (osip_message_t * sip,
 			      const char *start_of_header, const char **body);
 static int msg_osip_body_parse (osip_message_t * sip,
 				const char *start_of_buf,
-				const char **next_body);
-static int msg_osip_body_parse2 (osip_message_t * sip,
-				 const char *start_of_buf,
-				 const char **next_body,
-				 size_t length);
+				const char **next_body,
+				size_t length);
 
 
 static int
@@ -57,6 +54,8 @@ __osip_message_startline_parsereq (osip_message_t * dest, const char *buf,
   p2 = strchr (buf, ' ');
   if (p2 == NULL)
     return -1;
+  if (*(p2+1) == '\0' || *(p2+2) == '\0' )
+    return -1;
   if (p2 - buf == 0)
     {
       OSIP_TRACE (osip_trace
@@ -114,22 +113,21 @@ __osip_message_startline_parsereq (osip_message_t * dest, const char *buf,
 	    OSIP_TRACE (osip_trace
 			(__FILE__, __LINE__, OSIP_ERROR, NULL,
 			 "No crlf found\n"));
- 	    osip_free(dest->sip_method);
- 	    dest->sip_method = NULL;
- 	    osip_uri_free(dest->req_uri);
- 	    dest->req_uri = NULL;
+	    osip_free(dest->sip_method);
+	    dest->sip_method = NULL;
+	    osip_uri_free(dest->req_uri);
+	    dest->req_uri = NULL;
 	    return -1;
 	  }
       }
     if (hp - p1 < 2)
       {
- 	osip_free(dest->sip_method);
- 	dest->sip_method = NULL;
- 	osip_uri_free(dest->req_uri);
- 	dest->req_uri = NULL;
- 	return -1;
+	osip_free(dest->sip_method);
+	dest->sip_method = NULL;
+	osip_uri_free(dest->req_uri);
+	dest->req_uri = NULL;
+	return -1;
       }
- 
 
     dest->sip_version = (char *) osip_malloc (hp - p1);
     osip_strncpy (dest->sip_version, p1 + 1, (hp - p1 - 1));
@@ -420,7 +418,7 @@ msg_handle_multiple_values (osip_message_t * sip, char *hname, char *hvalue)
   char *end;			/* end of a header */
   char *quote1;			/* first quote of a pair of quotes   */
   char *quote2;			/* second quuote of a pair of quotes */
-
+  int   hname_len;
 
   beg = hvalue;
   end = NULL;
@@ -435,15 +433,29 @@ msg_handle_multiple_values (osip_message_t * sip, char *hname, char *hvalue)
 
   comma = strchr (ptr, ',');
 
+  hname_len = strlen(hname);
 
+#ifndef DONOTLOWERCASEHEADERS
   osip_tolower (hname);
+#endif
 
-  if (comma == NULL || (strncmp (hname, "date", 4) == 0 && strlen (hname) == 4) || strncmp (hname, "organization", 12) == 0 || (strncmp (hname, "to", 2) == 0 && strlen (hname) == 2) || (strncmp (hname, "from", 4) == 0 && strlen (hname) == 4)	/* AMD: BUG fix */
-      || strncmp (hname, "call-id", 7) == 0 || (strncmp (hname, "cseq", 4) == 0 && strlen (hname) == 4)	/* AMD: BUG fix */
-      || strncmp (hname, "subject", 7) == 0 || strncmp (hname, "user-agent", 10) == 0 || strncmp (hname, "server", 6) == 0 || strncmp (hname, "www-authenticate", 16) == 0	/* AMD: BUG fix */
-      || strncmp (hname, "authentication-info", 19) == 0 || strncmp (hname, "proxy-authenticate", 20) == 0 || strncmp (hname, "proxy-authorization", 19) == 0 || strncmp (hname, "proxy-authentication-info", 25) == 0	/* AMD: BUG fix */
-      || strncmp (hname, "expires", 7) == 0
-      || strncmp (hname, "authorization", 13) == 0)
+  if (comma == NULL
+      || (hname_len == 4 && osip_strncasecmp (hname, "date", 4) == 0)
+      || (hname_len == 2 && osip_strncasecmp (hname, "to", 2) == 0)
+      || (hname_len == 4 && osip_strncasecmp (hname, "from", 4) == 0)
+      || (hname_len == 7 && osip_strncasecmp (hname, "call-id", 7) == 0)
+      || (hname_len == 4 && osip_strncasecmp (hname, "cseq", 4) == 0)
+      || (hname_len == 7 && osip_strncasecmp (hname, "subject", 7) == 0)
+      || (hname_len == 7 && osip_strncasecmp (hname, "expires", 7) == 0)
+      || (hname_len == 6 && osip_strncasecmp (hname, "server", 6) == 0)
+      || (hname_len == 10 && osip_strncasecmp (hname, "user-agent", 10) == 0)
+      || (hname_len == 16 && osip_strncasecmp (hname, "www-authenticate", 16) == 0)
+      || (hname_len == 19 && osip_strncasecmp (hname, "authentication-info", 19) == 0)
+      || (hname_len == 18 && osip_strncasecmp (hname, "proxy-authenticate", 18) == 0)
+      || (hname_len == 19 && osip_strncasecmp (hname, "proxy-authorization", 19) == 0)
+      || (hname_len == 25 && osip_strncasecmp (hname, "proxy-authentication-info", 25) == 0)
+      || (hname_len == 12 && osip_strncasecmp (hname, "organization", 12) == 0)
+      || (hname_len == 13 && osip_strncasecmp (hname, "authorization", 13) == 0))
     /* there is no multiple header! likely      */
     /* to happen most of the time...            */
     /* or hname is a TEXT-UTF8-TRIM and may     */
@@ -592,7 +604,7 @@ msg_headers_parse (osip_message_t * sip, const char *start_of_header,
 	  hvalue = NULL;	/* some headers (subject) can be empty */
 	else
 	  {
-	    hvalue = (char *) osip_malloc ((end) - colon_index);
+	    hvalue = (char *) osip_malloc ((end) - colon_index+1);
 	    osip_strncpy (hvalue, colon_index + 1, (end) - colon_index - 1);
 	    osip_clrspace (hvalue);
 	  }
@@ -605,7 +617,7 @@ msg_headers_parse (osip_message_t * sip, const char *start_of_header,
       i = msg_handle_multiple_values (sip, hname, hvalue);
 
       osip_free (hname);
-      osip_free (hvalue);
+      if (hvalue!=NULL) osip_free (hvalue);
       if (i == -1)
 	{
 	  OSIP_TRACE (osip_trace
@@ -633,8 +645,8 @@ msg_headers_parse (osip_message_t * sip, const char *start_of_header,
 }
 
 static int
-msg_osip_body_parse2 (osip_message_t * sip, const char *start_of_buf,
-		      const char **next_body, size_t length)
+msg_osip_body_parse (osip_message_t * sip, const char *start_of_buf,
+		     const char **next_body, size_t length)
 {
   const char *start_of_body;
   const char *end_of_body;
@@ -669,8 +681,8 @@ msg_osip_body_parse2 (osip_message_t * sip, const char *start_of_buf,
 	return -1;	/* message does not end with CRLFCRLF, CRCR or LFLF */
       
       /* update length (without CRLFCRLF */
-      length = length-(start_of_buf-start_of_body);
-      if (length<=2)
+      length = length-(start_of_body-start_of_buf); /* fixed 24 08 2004 */
+      if (length<=0)
 	return -1;
       
       if (sip->content_length != NULL)
@@ -698,7 +710,7 @@ msg_osip_body_parse2 (osip_message_t * sip, const char *start_of_buf,
 	{
 	  OSIP_TRACE (osip_trace
 		      (__FILE__, __LINE__, OSIP_ERROR, NULL,
-		       "Message was not receieved enterely. lenngth=%i osip_body_len=%i\n",length, osip_body_len));
+		       "Message was not receieved enterely. length=%i osip_body_len=%i\n",length, osip_body_len));
 	  return -1;
 	}
 
@@ -707,139 +719,9 @@ msg_osip_body_parse2 (osip_message_t * sip, const char *start_of_buf,
       if (tmp == NULL)
 	return -1;
       memcpy (tmp, start_of_body, end_of_body - start_of_body);
-      
-      i = osip_message_set_body (sip, tmp);
-      osip_free (tmp);
-      if (i != 0)
-	return -1;
-      return 0;
-    }
-
-  /* find the boundary */
-  i = osip_generic_param_get_byname (sip->content_type->gen_params,
-				     "boundary", &ct_param);
-  if (i != 0)
-    return -1;
-
-  if (ct_param == NULL)
-    return -1;
-  if (ct_param->gvalue == NULL)
-    return -1;			/* No boundary but multiple headers??? */
-
-  sep_boundary = (char *) osip_malloc (strlen (ct_param->gvalue) + 3);
-  sprintf (sep_boundary, "--%s", ct_param->gvalue);
-
-  *next_body = NULL;
-  start_of_body = start_of_buf;
-  for (;;)
-    {
-      i =
-	__osip_find_next_occurence (sep_boundary, start_of_body,
-				    &start_of_body);
-      if (i == -1)
-	{
-	  osip_free (sep_boundary);
-	  return -1;
-	}
-      i =
-	__osip_find_next_occurence (sep_boundary,
-				    start_of_body + strlen (sep_boundary),
-				    &end_of_body);
-      if (i == -1)
-	{
-	  osip_free (sep_boundary);
-	  return -1;
-	}
-
-      /* this is the real beginning of body */
-      start_of_body = start_of_body + strlen (sep_boundary) + 2;
-
-      tmp = osip_malloc (end_of_body - start_of_body + 1);
-      memcpy (tmp, start_of_body, end_of_body - start_of_body);
       tmp[end_of_body - start_of_body]='\0';
-
-      i = osip_message_set_body_mime (sip, tmp);
-      osip_free (tmp);
-      if (i == -1)
-	{
-	  osip_free (sep_boundary);
-	  return -1;
-	}
-
-      if (strncmp (end_of_body + strlen (sep_boundary), "--", 2) == 0)
-	{			/* end of all bodies */
-	  *next_body = end_of_body;
-	  osip_free (sep_boundary);
-	  return 0;
-	}
-      /* continue on the next body */
-      start_of_body = end_of_body;
-    }
-  /* Unreachable code */
-  /* osip_free (sep_boundary); */
-  return -1;
-}
-
-/* internal method to parse the body */
-static int
-msg_osip_body_parse (osip_message_t * sip, const char *start_of_buf,
-		     const char **next_body)
-{
-  const char *start_of_body;
-  const char *end_of_body;
-  char *tmp;
-  int i;
-
-  char *sep_boundary;
-  osip_generic_param_t *ct_param;
-
-  if (sip->content_type == NULL
-      ||sip->content_type->type==NULL
-      ||sip->content_type->subtype==NULL)
-    return 0;		/* no body is attached */
-  
-  if (0!=osip_strcasecmp(sip->content_type->type, "multipart"))
-    {
-      size_t osip_body_len;
       
-      if (start_of_buf[0] == '\0')
-	return -1;		/* final CRLF is missing */
-      /* get rid of the first CRLF */
-      if ('\r' == start_of_buf[0])
-	{
-	  if ('\n' == start_of_buf[1])
-	    start_of_body = start_of_buf + 2;
-	  else
-	    start_of_body = start_of_buf + 1;
-	}
-      else if ('\n' == start_of_buf[0])
-	start_of_body = start_of_buf + 1;
-      else
-	return -1;	/* message does not end with CRLFCRLF, CRCR or LFLF */
-      
-      if (sip->content_length != NULL)
-	osip_body_len = osip_atoi (sip->content_length->value);
-      else
-	{			/* if content_length does not exist, set it. */
-	  char tmp[16];
-	  
-	  osip_body_len = strlen (start_of_body);
-	  sprintf (tmp, "%i", osip_body_len);
-	  i = osip_message_set_content_length (sip, tmp);
-	  if (i != 0)
-	    return -1;
-	}
-      
-      if (osip_body_len > strlen (start_of_body))	/* we do not receive the */
-	return -1;		/* complete message      */
-      /* end_of_body = start_of_body + strlen(start_of_body); */
-      end_of_body = start_of_body + osip_body_len;
-      tmp = osip_malloc (end_of_body - start_of_body + 2);
-      if (tmp == NULL)
-	return -1;
-      osip_strncpy (tmp, start_of_body, end_of_body - start_of_body);
-      
-      i = osip_message_set_body (sip, tmp);
+      i = osip_message_set_body (sip, tmp, end_of_body - start_of_body);
       osip_free (tmp);
       if (i != 0)
 	return -1;
@@ -883,12 +765,17 @@ msg_osip_body_parse (osip_message_t * sip, const char *start_of_buf,
 	}
 
       /* this is the real beginning of body */
-      start_of_body = start_of_body + strlen (sep_boundary) + 2;
+      start_of_body = start_of_body + strlen (sep_boundary) + 1;
+      if ('\n' == start_of_body[0] || '\r' == start_of_body[0])
+	start_of_body++;
 
-      tmp = osip_malloc (end_of_body - start_of_body + 1);
-      osip_strncpy (tmp, start_of_body, end_of_body - start_of_body);
-
-      i = osip_message_set_body_mime (sip, tmp);
+      tmp = osip_malloc (end_of_body - start_of_body + 2);
+      if (tmp == NULL)
+	return -1;
+      memcpy (tmp, start_of_body, end_of_body - start_of_body);
+      tmp[end_of_body - start_of_body]='\0';
+      
+      i = osip_message_set_body_mime (sip, tmp, end_of_body - start_of_body);
       osip_free (tmp);
       if (i == -1)
 	{
@@ -912,17 +799,13 @@ msg_osip_body_parse (osip_message_t * sip, const char *start_of_buf,
 
 /* osip_message_t *sip is filled while analysing buf */
 int
-osip_message_parse2 (osip_message_t * sip, const char *buf, size_t length)
+osip_message_parse (osip_message_t * sip, const char *buf, size_t length)
 {
   int i;
   const char *next_header_index;
   char *tmp;
   char *beg;
-#ifdef WIN32
-  tmp = _alloca (length + 2);
-#else
-  tmp = alloca (length + 2);
-#endif
+  tmp = osip_malloc (length + 2);
   if (tmp==NULL)
     {
       OSIP_TRACE (osip_trace
@@ -941,6 +824,7 @@ osip_message_parse2 (osip_message_t * sip, const char *buf, size_t length)
       OSIP_TRACE (osip_trace
 		  (__FILE__, __LINE__, OSIP_ERROR, NULL,
 		   "Could not parse start line of message.\n"));
+      osip_free(beg);
       return -1;
     }
   tmp = (char *) next_header_index;
@@ -952,6 +836,7 @@ osip_message_parse2 (osip_message_t * sip, const char *buf, size_t length)
       OSIP_TRACE (osip_trace
 		  (__FILE__, __LINE__, OSIP_ERROR, NULL,
 		   "error in msg_headers_parse()\n"));
+      osip_free(beg);
       return -1;
     }
   tmp = (char *) next_header_index;
@@ -962,10 +847,12 @@ osip_message_parse2 (osip_message_t * sip, const char *buf, size_t length)
       /* this is mantory in the oSIP stack */
       if (sip->content_length == NULL)
 	osip_message_set_content_length (sip, "0");
+      osip_free(beg);
       return 0;			/* no body found */
     }
 
-  i = msg_osip_body_parse2 (sip, tmp, &next_header_index, length-(beg-tmp));
+  i = msg_osip_body_parse (sip, tmp, &next_header_index, length-(tmp-beg));
+  osip_free(beg);
   if (i == -1)
     {
       OSIP_TRACE (osip_trace
@@ -981,69 +868,6 @@ osip_message_parse2 (osip_message_t * sip, const char *buf, size_t length)
   return 0;
 }
 
-/* osip_message_t *sip is filled while analysing buf */
-int
-osip_message_parse (osip_message_t * sip, const char *buf)
-{
-  int i;
-  const char *next_header_index;
-  char *tmp;
-
-#ifdef WIN32
-  tmp = _alloca (strlen (buf) + 2);
-#else
-  tmp = alloca (strlen (buf) + 2);
-#endif
-  osip_strncpy (tmp, buf, strlen (buf));
-  osip_util_replace_all_lws (tmp);
-  /* parse request or status line */
-  i = __osip_message_startline_parse (sip, tmp, &next_header_index);
-  if (i == -1)
-    {
-      OSIP_TRACE (osip_trace
-		  (__FILE__, __LINE__, OSIP_ERROR, NULL,
-		   "Could not parse start line of message.\n"));
-      return -1;
-    }
-  tmp = (char *) next_header_index;
-
-  /* parse headers */
-  i = msg_headers_parse (sip, tmp, &next_header_index);
-  if (i == -1)
-    {
-      OSIP_TRACE (osip_trace
-		  (__FILE__, __LINE__, OSIP_ERROR, NULL,
-		   "error in msg_headers_parse()\n"));
-      return -1;
-    }
-  tmp = (char *) next_header_index;
-
-  /* this is a *very* simple test... (which handle most cases...) */
-  if (strlen (tmp) < 3)
-    {
-      /* this is mantory in the oSIP stack */
-      if (sip->content_length == NULL)
-	osip_message_set_content_length (sip, "0");
-      return 0;			/* no body found */
-    }
-
-  i = msg_osip_body_parse (sip, tmp, &next_header_index);
-  if (i == -1)
-    {
-      OSIP_TRACE (osip_trace
-		  (__FILE__, __LINE__, OSIP_ERROR, NULL,
-		   "error in msg_osip_body_parse()\n"));
-      return -1;
-    }
-  tmp = (char *) next_header_index;
-
-  /* this is mandatory in the oSIP stack */
-  if (sip->content_length == NULL)
-    osip_message_set_content_length (sip, "0");
-
-  return 0;
-}
-
 /* This method just add a received parameter in the Via
    as requested by rfc3261 */
 int
@@ -1125,11 +949,13 @@ osip_message_get_reason (int replycode)
     {409, "Conflict"},
     {410, "Gone"},
     {411, "Length Required"},
+    {412, "Conditional Request Failed"},
     {413, "Request Entity Too Large"},
     {414, "Request-URI Too Large"},
     {415, "Unsupported Media Type"},
     {416, "Unsupported Uri Scheme"},
     {420, "Bad Extension"},
+    {422, "Session Interval Too Small"},
     {423, "Interval Too Short"},
     {480, "Temporarily not available"},
     {481, "Call Leg/Transaction Does Not Exist"},
