@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -184,11 +184,11 @@ strcat_simple_header (char **_string, size_t * malloc_size,
   if (ptr_header != NULL)
     {
       if (*malloc_size < message - string + 100 + size_of_header)
-	/* take some memory avoid to realloc too much often */
+	/* take some memory avoid to osip_realloc too much often */
 	{			/* should not happen often */
 	  size_t size = message - string;
 	  *malloc_size = message - string + size_of_header + 100;
-	  string = realloc (string, *malloc_size);
+	  string = osip_realloc (string, *malloc_size);
 	  if (string == NULL)
 	    {
 	      *_string = NULL;
@@ -211,7 +211,7 @@ strcat_simple_header (char **_string, size_t * malloc_size,
 	{
 	  size_t size = message - string;
 	  *malloc_size = message - string + strlen (tmp) + 100;
-	  string = realloc (string, *malloc_size);
+	  string = osip_realloc (string, *malloc_size);
 	  if (string == NULL)
 	    {
 	      *_string = NULL;
@@ -254,11 +254,11 @@ strcat_headers_one_per_line (char **_string, size_t * malloc_size,
       elt = (void *) osip_list_get (headers, pos);
 
       if (*malloc_size < message - string + 100 + size_of_header)
-	/* take some memory avoid to realloc too much often */
+	/* take some memory avoid to osip_realloc too much often */
 	{			/* should not happen often */
 	  size_t size = message - string;
 	  *malloc_size = message - string + size_of_header + 100;
-	  string = realloc (string, *malloc_size);
+	  string = osip_realloc (string, *malloc_size);
 	  if (string == NULL)
 	    {
 	      *_string = NULL;
@@ -282,7 +282,7 @@ strcat_headers_one_per_line (char **_string, size_t * malloc_size,
 	{
 	  size_t size = message - string;
 	  *malloc_size = message - string + strlen (tmp) + 100;
-	  string = realloc (string, *malloc_size);
+	  string = osip_realloc (string, *malloc_size);
 	  if (string == NULL)
 	    {
 	      *_string = NULL;
@@ -324,11 +324,11 @@ strcat_headers_all_on_one_line (char **_string, size_t * malloc_size,
   while (!osip_list_eol (headers, pos))
     {
       if (*malloc_size < message - string + 100 + size_of_header)
-	/* take some memory avoid to realloc too much often */
+	/* take some memory avoid to osip_realloc too much often */
 	{			/* should not happen often */
 	  size_t size = message - string;
 	  *malloc_size = message - string + size_of_header + 100;
-	  string = realloc (string, *malloc_size);
+	  string = osip_realloc (string, *malloc_size);
 	  if (string == NULL)
 	    {
 	      *_string = NULL;
@@ -357,7 +357,7 @@ strcat_headers_all_on_one_line (char **_string, size_t * malloc_size,
 	    {
 	      size_t size = message - string;
 	      *malloc_size = message - string + (int) strlen (tmp) + 100;
-	      string = realloc (string, *malloc_size);
+	      string = osip_realloc (string, *malloc_size);
 	      if (string == NULL)
 		{
 		  *_string = NULL;
@@ -408,9 +408,10 @@ osip_message_force_update (osip_message_t * sip)
 }
 
 int
-osip_message_to_str (osip_message_t * sip, char **dest)
+osip_message_to_str (osip_message_t * sip, char **dest, size_t *message_length)
 {
   size_t malloc_size;
+  size_t total_length = 0;
   /* Added at SIPit day1 */
   char *start_of_bodies;
   char *content_length_to_modify = NULL;
@@ -430,15 +431,14 @@ osip_message_to_str (osip_message_t * sip, char **dest)
     if (1 == osip_message_get__property (sip))
       {				/* message is already available in "message" */
 
-	*dest = osip_strdup (sip->message);	/* is we just return the pointer, people will
-						   get issues while upgrading the library. This
-						   is because they are used to call free(*dest)
-						   right after using the buffer. This may be
-						   changed while moving to another branch
-						   developpement. replacement line will be:
-						   *dest = sip->message; */
+	*dest = osip_malloc(sip->message_length+1);
+	if (*dest==NULL)
+	  return -1;
+	memcpy(*dest, sip->message, sip->message_length);
+	(*dest)[sip->message_length]='\0';
+	if (message_length!=NULL)
+	  *message_length = sip->message_length;
 	return 0;
-
       }
     else
       {
@@ -637,7 +637,7 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 	{
 	  size_t size = message - *dest;
 	  malloc_size = message - *dest + 16 + 100;
-	  *dest = realloc (*dest, malloc_size);
+	  *dest = osip_realloc (*dest, malloc_size);
 	  if (*dest == NULL)
 	    return -1;
 	  message = *dest + size;
@@ -783,6 +783,33 @@ osip_message_to_str (osip_message_t * sip, char **dest)
     }
   message = next;
 
+  i =
+    strcat_headers_one_per_line (dest, &malloc_size, &message,
+				 sip->authentication_infos,
+				 "Authentication-Info: ", 21,
+				 ((int (*)(void *, char **))
+				  &osip_authentication_info_to_str), &next);
+  if (i != 0)
+    {
+      osip_free (*dest);
+      *dest = NULL;
+      return -1;
+    }
+  message = next;
+
+  i =
+    strcat_headers_one_per_line (dest, &malloc_size, &message,
+				 sip->proxy_authentication_infos,
+				 "Proxy-Authentication-Info: ", 27,
+				 ((int (*)(void *, char **))
+				  &osip_authentication_info_to_str), &next);
+  if (i != 0)
+    {
+      osip_free (*dest);
+      *dest = NULL;
+      return -1;
+    }
+  message = next;
 
 
   /* we have to create the body before adding the contentlength */
@@ -791,7 +818,7 @@ osip_message_to_str (osip_message_t * sip, char **dest)
     {
       size_t size = message - *dest;
       malloc_size = message - *dest + 16 + 100;
-      *dest = realloc (*dest, malloc_size);
+      *dest = osip_realloc (*dest, malloc_size);
       if (*dest == NULL)
 	return -1;
       message = *dest + size;
@@ -840,19 +867,26 @@ osip_message_to_str (osip_message_t * sip, char **dest)
   osip_strncpy (message, CRLF, 2);
   message = message + 2;
 
+  start_of_bodies = message;
+  total_length = start_of_bodies - *dest;
+
   if (osip_list_eol (sip->bodies, 0))
     {
       /* same remark as at the beginning of the method */
       sip->message_property = 1;
       sip->message = osip_strdup (*dest);
+      sip->message_length = total_length;
+      if (message_length!=NULL)
+	*message_length = total_length;
+
       return 0;			/* it's all done */
     }
-  start_of_bodies = message;
 
   pos = 0;
   while (!osip_list_eol (sip->bodies, pos))
     {
       osip_body_t *body;
+      size_t body_length;
 
       body = (osip_body_t *) osip_list_get (sip->bodies, pos);
 
@@ -864,7 +898,7 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 	  message = message + 2;
 	}
 
-      i = osip_body_to_str (body, &tmp);
+      i = osip_body_to_str (body, &tmp, &body_length);
       if (i != 0)
 	{
 	  osip_free (*dest);
@@ -872,19 +906,28 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 	  return -1;
 	}
 
-      if (malloc_size < message - *dest + 100 + strlen (tmp))
+      if (malloc_size < message - *dest + 100 + body_length)
 	{
 	  size_t size = message - *dest;
-	  malloc_size = message - *dest + strlen (tmp) + 100;
-	  *dest = realloc (*dest, malloc_size);
+	  int offset_of_body;
+	  int offset_content_length_to_modify;
+	  offset_of_body = start_of_bodies - *dest;
+	  if (content_length_to_modify != NULL)
+	    offset_content_length_to_modify = content_length_to_modify - *dest;
+	  malloc_size = message - *dest + body_length + 100;
+	  *dest = osip_realloc (*dest, malloc_size);
 	  if (*dest == NULL)
 	    return -1;
+	  start_of_bodies = *dest + offset_of_body;
+	  if (content_length_to_modify != NULL)
+	    content_length_to_modify = *dest + offset_content_length_to_modify;
 	  message = *dest + size;
 	}
 
-      osip_strncpy (message, tmp, strlen (tmp));
+      memcpy (message, tmp, body_length);
+      message[body_length]='\0';
       osip_free (tmp);
-      message = message + strlen (message);
+      message = message + body_length;
 
       pos++;
     }
@@ -910,16 +953,24 @@ osip_message_to_str (osip_message_t * sip, char **dest)
 
   /* we NOW have the length of bodies: */
   {
-    size_t size = strlen (start_of_bodies);
-    char tmp[15];
-
-    sprintf (tmp, "%i", size);
+    size_t size = message - start_of_bodies;
+    char tmp2[15];
+    total_length += size;
+    sprintf (tmp2, "%i", size);
     /* do not use osip_strncpy here! */
-    strncpy (content_length_to_modify + 5 - strlen (tmp), tmp, strlen (tmp));
+    strncpy (content_length_to_modify + 5 - strlen (tmp2), tmp2, strlen (tmp2));
   }
 
   /* same remark as at the beginning of the method */
   sip->message_property = 1;
-  sip->message = osip_strdup (*dest);
+  sip->message=osip_malloc(total_length+1);
+  if(sip->message!=NULL)
+    {
+      memcpy(sip->message,*dest,total_length);
+      sip->message[total_length]='\0';
+      sip->message_length = total_length;
+      if(message_length!=NULL)
+	*message_length = total_length;
+    }
   return 0;
 }
