@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -43,69 +43,74 @@ static __osip_message_config_t pconfig[NUMBER_OF_HEADERS];
 int
 parser_init ()
 {
+  int i = 0;
 
-  pconfig[0].hname = ACCEPT;
-  pconfig[0].setheader = (&osip_message_set_accept);
-  pconfig[1].hname = ACCEPT_ENCODING;
-  pconfig[1].setheader = (&osip_message_set_accept_encoding);
-  pconfig[2].hname = ACCEPT_LANGUAGE;
-  pconfig[2].setheader = (&osip_message_set_accept_language);
-  pconfig[3].hname = ALERT_INFO;
-  pconfig[3].setheader = (&osip_message_set_alert_info);
-  pconfig[4].hname = ALLOW;
-  pconfig[4].setheader = (&osip_message_set_allow);
-  pconfig[5].hname = AUTHORIZATION;
-  pconfig[5].setheader = (&osip_message_set_authorization);
-  pconfig[6].hname = CONTENT_TYPE_SHORT;	/* "l" */
-  pconfig[6].setheader = (&osip_message_set_content_type);
-  pconfig[7].hname = CALL_ID;
-  pconfig[7].setheader = (&osip_message_set_call_id);
-  pconfig[8].hname = CALL_INFO;
-  pconfig[8].setheader = (&osip_message_set_call_info);
-  pconfig[9].hname = CONTACT;
-  pconfig[9].setheader = (&osip_message_set_contact);
-  pconfig[10].hname = CONTENT_ENCODING;
-  pconfig[10].setheader = (&osip_message_set_content_encoding);
-  pconfig[11].hname = CONTENT_LENGTH;
-  pconfig[11].setheader = (&osip_message_set_content_length);
-  pconfig[12].hname = CONTENT_TYPE;
-  pconfig[12].setheader = (&osip_message_set_content_type);
-  pconfig[13].hname = CSEQ;
-  pconfig[13].setheader = (&osip_message_set_cseq);
-  pconfig[14].hname = CONTENT_ENCODING_SHORT;	/* "e" */
-  pconfig[14].setheader = (&osip_message_set_content_encoding);
-  pconfig[15].hname = ERROR_INFO;
-  pconfig[15].setheader = (&osip_message_set_error_info);
-  pconfig[16].hname = FROM_SHORT;	/* "f" */
-  pconfig[16].setheader = (&osip_message_set_from);
-  pconfig[17].hname = FROM;
-  pconfig[17].setheader = (&osip_message_set_from);
-  pconfig[18].hname = CALL_ID_SHORT;	/* "i" */
-  pconfig[18].setheader = (&osip_message_set_call_id);
-  pconfig[19].hname = CONTENT_LENGTH_SHORT;	/* "l" */
-  pconfig[19].setheader = (&osip_message_set_content_length);
-  pconfig[20].hname = CONTACT_SHORT;	/* "m" */
-  pconfig[20].setheader = (&osip_message_set_contact);
-  pconfig[21].hname = MIME_VERSION;
-  pconfig[21].setheader = (&osip_message_set_mime_version);
-  pconfig[22].hname = PROXY_AUTHENTICATE;
-  pconfig[22].setheader = (&osip_message_set_proxy_authenticate);
-  pconfig[23].hname = PROXY_AUTHORIZATION;
-  pconfig[23].setheader = (&osip_message_set_proxy_authorization);
-  pconfig[24].hname = RECORD_ROUTE;
-  pconfig[24].setheader = (&osip_message_set_record_route);
-  pconfig[25].hname = ROUTE;
-  pconfig[25].setheader = (&osip_message_set_route);
-  pconfig[26].hname = TO_SHORT;
-  pconfig[26].setheader = (&osip_message_set_to);
-  pconfig[27].hname = TO;
-  pconfig[27].setheader = (&osip_message_set_to);
-  pconfig[28].hname = VIA_SHORT;
-  pconfig[28].setheader = (&osip_message_set_via);
-  pconfig[29].hname = VIA;
-  pconfig[29].setheader = (&osip_message_set_via);
-  pconfig[30].hname = WWW_AUTHENTICATE;
-  pconfig[30].setheader = (&osip_message_set_www_authenticate);
+  pconfig[i].hname = ACCEPT;
+  pconfig[i++].setheader = (&osip_message_set_accept);
+  pconfig[i].hname = ACCEPT_ENCODING;
+  pconfig[i++].setheader = (&osip_message_set_accept_encoding);
+  pconfig[i].hname = ACCEPT_LANGUAGE;
+  pconfig[i++].setheader = (&osip_message_set_accept_language);
+  pconfig[i].hname = ALERT_INFO;
+  pconfig[i++].setheader = (&osip_message_set_alert_info);
+  pconfig[i].hname = ALLOW;
+  pconfig[i++].setheader = (&osip_message_set_allow);
+  pconfig[i].hname = AUTHENTICATION_INFO;
+  pconfig[i++].setheader = (&osip_message_set_authentication_info);
+  pconfig[i].hname = AUTHORIZATION;
+  pconfig[i++].setheader = (&osip_message_set_authorization);
+  pconfig[i].hname = CONTENT_TYPE_SHORT;	/* "l" */
+  pconfig[i++].setheader = (&osip_message_set_content_type);
+  pconfig[i].hname = CALL_ID;
+  pconfig[i++].setheader = (&osip_message_set_call_id);
+  pconfig[i].hname = CALL_INFO;
+  pconfig[i++].setheader = (&osip_message_set_call_info);
+  pconfig[i].hname = CONTACT;
+  pconfig[i++].setheader = (&osip_message_set_contact);
+  pconfig[i].hname = CONTENT_ENCODING;
+  pconfig[i++].setheader = (&osip_message_set_content_encoding);
+  pconfig[i].hname = CONTENT_LENGTH;
+  pconfig[i++].setheader = (&osip_message_set_content_length);
+  pconfig[i].hname = CONTENT_TYPE;
+  pconfig[i++].setheader = (&osip_message_set_content_type);
+  pconfig[i].hname = CSEQ;
+  pconfig[i++].setheader = (&osip_message_set_cseq);
+  pconfig[i].hname = CONTENT_ENCODING_SHORT;	/* "e" */
+  pconfig[i++].setheader = (&osip_message_set_content_encoding);
+  pconfig[i].hname = ERROR_INFO;
+  pconfig[i++].setheader = (&osip_message_set_error_info);
+  pconfig[i].hname = FROM_SHORT;	/* "f" */
+  pconfig[i++].setheader = (&osip_message_set_from);
+  pconfig[i].hname = FROM;
+  pconfig[i++].setheader = (&osip_message_set_from);
+  pconfig[i].hname = CALL_ID_SHORT;	/* "i" */
+  pconfig[i++].setheader = (&osip_message_set_call_id);
+  pconfig[i].hname = CONTENT_LENGTH_SHORT;	/* "l" */
+  pconfig[i++].setheader = (&osip_message_set_content_length);
+  pconfig[i].hname = CONTACT_SHORT;	/* "m" */
+  pconfig[i++].setheader = (&osip_message_set_contact);
+  pconfig[i].hname = MIME_VERSION;
+  pconfig[i++].setheader = (&osip_message_set_mime_version);
+  pconfig[i].hname = PROXY_AUTHENTICATE;
+  pconfig[i++].setheader = (&osip_message_set_proxy_authenticate);
+  pconfig[i].hname = PROXY_AUTHENTICATION_INFO;
+  pconfig[i++].setheader = (&osip_message_set_proxy_authentication_info);
+  pconfig[i].hname = PROXY_AUTHORIZATION;
+  pconfig[i++].setheader = (&osip_message_set_proxy_authorization);
+  pconfig[i].hname = RECORD_ROUTE;
+  pconfig[i++].setheader = (&osip_message_set_record_route);
+  pconfig[i].hname = ROUTE;
+  pconfig[i++].setheader = (&osip_message_set_route);
+  pconfig[i].hname = TO_SHORT;
+  pconfig[i++].setheader = (&osip_message_set_to);
+  pconfig[i].hname = TO;
+  pconfig[i++].setheader = (&osip_message_set_to);
+  pconfig[i].hname = VIA_SHORT;
+  pconfig[i++].setheader = (&osip_message_set_via);
+  pconfig[i].hname = VIA;
+  pconfig[i++].setheader = (&osip_message_set_via);
+  pconfig[i].hname = WWW_AUTHENTICATE;
+  pconfig[i++].setheader = (&osip_message_set_www_authenticate);
 
   return 0;
 }
