@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -28,6 +28,16 @@
 
 #include <osipparser2/osip_port.h>
 
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+
 #ifdef HAVE_CTYPE_H
 #include <ctype.h>
 #endif
@@ -65,12 +75,20 @@
 #include <pthread.h>
 #endif
 
+
 FILE *logfile = NULL;
 int tracing_table[END_TRACE_LEVEL];
 static int use_syslog = 0;
+static osip_trace_func_t *trace_func = 0;
 
 static unsigned int random_seed_set = 0;
 
+#ifndef WIN32
+osip_malloc_func_t  *osip_malloc_func = 0;
+osip_realloc_func_t *osip_realloc_func = 0;
+osip_free_func_t    *osip_free_func = 0;
+#endif
+
 #ifndef WIN32_USE_CRYPTO
 unsigned int
 osip_build_random_number ()
@@ -81,18 +99,45 @@ osip_fallback_random_number ()
 {
   if (!random_seed_set)
     {
-#ifndef WIN32
-      struct timeval tv;
-
-      gettimeofday (&tv, NULL);
-      srand (tv.tv_usec);
+      unsigned int ticks;
+#ifdef WIN32
+      LARGE_INTEGER lCount;
+      QueryPerformanceCounter(&lCount);
+      ticks = lCount.LowPart + lCount.HighPart;
+#elif defined(_WIN32_WCE)
+      ticks = GetTickCount();
 #else
-      srand (time (NULL));
+      struct timeval tv;
+      int fd;
+      gettimeofday (&tv, NULL);
+      ticks = tv.tv_sec + tv.tv_usec;
+      fd=open("/dev/urandom",O_RDONLY);
+      if (fd > 0)
+	{
+          unsigned int r;
+	  int i;
+          for (i=0;i<512;i++)
+	    {
+	      read(fd, &r, sizeof(r));
+	      ticks += r;
+	    }
+	  close(fd);
+	}
+#endif
+
+#ifdef HAVE_LRAND48
+      srand48 (ticks);
+#else
+      srand (ticks);
 #endif
       random_seed_set = 1;
     }
 
+#ifdef HAVE_LRAND48
+  return lrand48 ();
+#else
   return rand ();
+#endif
 }
 
 #ifdef WIN32_USE_CRYPTO
@@ -145,7 +190,7 @@ char *
 osip_strncpy (char *dest, const char *src, size_t length)
 {
 #ifdef WIN32
-  memcpy (dest, src, length);
+  strncpy (dest, src, length);
 #else
   strncpy (dest, src, length);
 #endif
@@ -167,7 +212,7 @@ __osip_sdp_append_string (char *string, size_t size, char *cur,
       size_t length2;
 
       length2 = cur - string;
-      string = realloc (string, size + length + 10);
+      string = osip_realloc (string, size + length + 10);
       cur = string + length2;	/* the initial allocation may have changed! */
     }
   osip_strncpy (cur, string_osip_to_append, length);
@@ -198,6 +243,7 @@ osip_usleep (int useconds)
 #endif
 }
 
+#undef osip_strdup
 
 char *
 osip_strdup (const char *ch)
@@ -235,7 +281,7 @@ osip_tolower (char *word)
   for (; *word; word++)
     *word = (char) tolower (*word);
 #else
-  int i;
+  size_t i;
   size_t len = strlen (word);
 
   for (i = 0; i <= len - 1; i++)
@@ -507,6 +553,10 @@ osip_dequote (char *s)
 /**********************************************************/
 #ifndef ENABLE_TRACE
 void
+osip_trace_initialize_func (osip_trace_level_t level, osip_trace_func_t *func)
+{
+}
+void
 osip_trace_initialize_syslog (osip_trace_level_t level, char *ident)
 {
 }
@@ -536,7 +586,7 @@ osip_is_trace_level_activate (osip_trace_level_t level)
 void
 osip_trace_initialize (osip_trace_level_t level, FILE * file)
 {
-  int i = 0;
+  osip_trace_level_t i = 0;
 
   /* enable trace in log file by default */
   logfile = NULL;
@@ -561,7 +611,7 @@ osip_trace_initialize (osip_trace_level_t level, FILE * file)
 void
 osip_trace_initialize_syslog (osip_trace_level_t level, char *ident)
 {
-  int i = 0;
+  osip_trace_level_t i = 0;
 #if defined (HAVE_SYSLOG_H)
   openlog (ident, LOG_CONS | LOG_PID, LOG_DAEMON);
   use_syslog = 1;
@@ -577,6 +627,37 @@ osip_trace_initialize_syslog (osip_trace_level_t level, char *ident)
     }
 }
 
+void
+osip_trace_enable_until_level (osip_trace_level_t level)
+{
+  int i = 0;
+  while (i < END_TRACE_LEVEL)
+    {
+      if (i < level)
+	tracing_table[i] = LOG_TRUE;
+      else
+	tracing_table[i] = LOG_FALSE;
+      i++;
+    }
+}
+
+void
+osip_trace_initialize_func (osip_trace_level_t level, osip_trace_func_t *func)
+{
+  int i = 0;
+  trace_func = func;
+
+  /* enable all lower levels */
+  while (i < END_TRACE_LEVEL)
+    {
+      if (i < level)
+	tracing_table[i] = LOG_TRUE;
+      else
+	tracing_table[i] = LOG_FALSE;
+      i++;
+    }
+}
+
 /* enable a special debugging level! */
 void
 osip_trace_enable_level (osip_trace_level_t level)
@@ -607,18 +688,18 @@ osip_trace (char *fi, int li, osip_trace_level_t level, FILE * f, char *chfr,
 #ifdef ENABLE_TRACE
 
 #if !defined(WIN32) && !defined(SYSTEM_LOGGER_ENABLED)
-  if (logfile == NULL && use_syslog == 0)
+  if (logfile == NULL && use_syslog == 0 && trace_func == NULL)
     {				/* user did not initialize logger.. */
       return 1;
     }
 #endif
 
-  if (f == NULL)
-    f = logfile;
-
   if (tracing_table[level] == LOG_FALSE)
     return 0;
 
+  if (f == NULL && trace_func == NULL)
+    f = logfile;
+
   VA_START (ap, chfr);
 
 #ifdef __VXWORKS_OS__
@@ -649,6 +730,10 @@ osip_trace (char *fi, int li, osip_trace_level_t level, FILE * f, char *chfr,
 
       fflush (f);
     }
+  else if (trace_func) 
+    {
+      trace_func(fi, li, level, chfr, ap);
+    }
 #if defined (HAVE_SYSLOG_H)
   else if (use_syslog == 1)
     {
@@ -724,17 +809,42 @@ osip_trace (char *fi, int li, osip_trace_level_t level, FILE * f, char *chfr,
   return 0;
 }
 
+
+
 #ifdef WIN32
 
+#undef osip_malloc
 void *osip_malloc(size_t size)
 {
-	return malloc(size);
+  void *ptr = malloc(size);
+  if(ptr!=NULL)
+    memset(ptr,0,size);
+  return ptr;
 }
 
+#undef osip_realloc
+void *osip_realloc(void *ptr, size_t size)
+{
+  return realloc(ptr, size);
+}
+
+#undef osip_free
 void osip_free(void *ptr)
 {
-	if (ptr==NULL) return;
-	free(ptr);
+  if (ptr==NULL) return;
+  free(ptr);
 }
 
-#endif
\ No newline at end of file
+#else
+
+void osip_set_allocators(osip_malloc_func_t  *malloc_func, 
+                         osip_realloc_func_t *realloc_func, 
+                         osip_free_func_t    *free_func)
+{
+    osip_malloc_func = malloc_func;
+    osip_realloc_func = realloc_func;
+    osip_free_func = free_func;
+}
+
+#endif
+
