@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -140,6 +140,7 @@ int osip_rfc3264_reset_media (struct osip_rfc3264 *config)
 /**
  * Add a media (for audio) in the configuration.
  * @param config The element to work on.
+ * @param med The media element to add.
  * @param pos The index of the media element to add.
  */
 int osip_rfc3264_add_audio_media (struct osip_rfc3264 *config, sdp_media_t *med, int pos)
@@ -178,6 +179,7 @@ int osip_rfc3264_del_audio_media (struct osip_rfc3264 *config, int pos)
 /**
  * Add a media (for video) in the configuration.
  * @param config The element to work on.
+ * @param med The media element to add.
  * @param pos The index of the media element to add.
  */
 int osip_rfc3264_add_video_media (struct osip_rfc3264 *config, sdp_media_t *med, int pos)
@@ -216,6 +218,7 @@ int osip_rfc3264_del_video_media (struct osip_rfc3264 *config, int pos)
 /**
  * Add a media (for t38) in the configuration.
  * @param config The element to work on.
+ * @param med The media element to add.
  * @param pos The index of the media element to add.
  */
 int osip_rfc3264_add_t38_media (struct osip_rfc3264 *config, sdp_media_t *med, int pos)
@@ -254,6 +257,8 @@ int osip_rfc3264_del_t38_media (struct osip_rfc3264 *config, int pos)
 /**
  * Search for support of a special codec.
  * @param config The element to work on.
+ * @param payload The payload to find.
+ * @param rtpmap The rtpmap for the payload.
  */
   sdp_media_t *osip_rfc3264_find_audio (struct osip_rfc3264 *config, char *payload,
 					char *rtpmap)
@@ -313,6 +318,8 @@ int osip_rfc3264_del_t38_media (struct osip_rfc3264 *config, int pos)
 /**
  * Search for support of a special codec.
  * @param config The element to work on.
+ * @param payload The payload to find.
+ * @param rtpmap The rtpmap for the payload.
  */
   sdp_media_t *osip_rfc3264_find_video (struct osip_rfc3264 *config, char *payload,
 					char *rtpmap)
@@ -372,6 +379,7 @@ int osip_rfc3264_del_t38_media (struct osip_rfc3264 *config, int pos)
 /**
  * Search for support of a special codec.
  * @param config The element to work on.
+ * @param payload The payload to find.
  */
   sdp_media_t *osip_rfc3264_find_t38 (struct osip_rfc3264 *config, char *payload)
 {
@@ -383,6 +391,7 @@ int osip_rfc3264_del_t38_media (struct osip_rfc3264 *config, int pos)
 /**
  * Search for support of a special codec.
  * @param config The element to work on.
+ * @param payload The payload to find.
  */
   sdp_media_t *osip_rfc3264_find_app (struct osip_rfc3264 *config, char *payload)
 {
@@ -769,7 +778,7 @@ c=IN IP4 TOREPLACE\r\n");
 	snprintf(tmp, 199, "m=%s %c %s ", med->m_media, inactive, med->m_proto);
 #endif
 	}
-      else if (med->m_media!=NULL && med->m_proto!=NULL && med->m_number_of_port==NULL)
+      else if (med->m_media!=NULL && med->m_proto!=NULL && med->m_number_of_port!=NULL)
 	{
 #if (defined WIN32 || defined _WIN32_WCE) 
 	  _snprintf(tmp, 199, "m=%s %c %s/%s ", med->m_media, inactive, med->m_proto, med->m_number_of_port);
