@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -170,6 +170,8 @@ osip_uri_parse (osip_uri_t * url, const char *buf)
 
   if (host == NULL)
     host = username;
+  else if (username[1] == '@') /* username is empty */
+    host = username+1;
   else
     /* username exists */
     {
@@ -617,7 +619,7 @@ osip_uri_to_str (const osip_uri_t * url, char **dest)
 	    plen = strlen (tmp1) + strlen (tmp2) + 3;
 	  }
 	len = len + plen;
-	buf = (char *) realloc (buf, len);
+	buf = (char *) osip_realloc (buf, len);
 	tmp = buf;
 	tmp = tmp + strlen (tmp);
 	if (u_param->gvalue == NULL)
@@ -654,15 +656,13 @@ osip_uri_to_str (const osip_uri_t * url, char **dest)
 	plen = strlen (tmp1) + strlen (tmp2) + 4;
 
 	len = len + plen;
-	buf = (char *) realloc (buf, len);
+	buf = (char *) osip_realloc (buf, len);
 	tmp = buf;
 	tmp = tmp + strlen (tmp);
 	if (pos == 0)
-	  {
-	    sprintf (tmp, "?%s=%s", u_header->gname, u_header->gvalue);
-	  }
+	  sprintf (tmp, "?%s=%s", tmp1, tmp2);
 	else
-	  sprintf (tmp, "&%s=%s", u_header->gname, u_header->gvalue);
+	  sprintf (tmp, "&%s=%s", tmp1, tmp2);
 	osip_free (tmp1);
 	osip_free (tmp2);
 	pos++;
@@ -936,7 +936,7 @@ __osip_uri_escape_nonascii_and_nondef (const char *string, const char *def)
 	  if (newlen > alloc)
 	    {
 	      alloc *= 2;
-	      ns = realloc (ns, alloc);
+	      ns = osip_realloc (ns, alloc);
 	      if (!ns)
 		return NULL;
 	    }
@@ -1003,8 +1003,19 @@ __osip_uri_unescape (char *string)
 	  if (sscanf (ptr + 1, "%02X", &hex))
 	    {
 	      in = (unsigned char) hex;
-	      ptr += 2;
-	      alloc -= 2;
+              if (*(ptr+2) &&
+                  ((*(ptr+2) >= '0' && *(ptr+2) <= '9') ||
+                   (*(ptr+2) >= 'a' && *(ptr+2) <= 'f') ||
+                   (*(ptr+2) >= 'A' && *(ptr+2) <= 'F')))
+                {
+                  alloc -= 2;
+                  ptr += 2;
+                }
+              else
+                {
+                  alloc -= 1;
+                  ptr += 1;
+                }
 	    }
 	}
 
@@ -1014,13 +1025,9 @@ __osip_uri_unescape (char *string)
   string[index] = 0;		/* terminate it */
 }
 
-/* 
-   Robin Nayathodan <roooot@softhome.net> 
-   N.K Electronics INDIA
 
-   RFC3261 16.5 
+/* RFC3261 16.5 
  */
-
 int
 osip_uri_to_str_canonical (const osip_uri_t * url, char **dest)
 {
