@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -343,7 +343,7 @@ osip_via_to_str (const osip_via_t * via, char **dest)
 	else
 	  plen = strlen (u_param->gname) + strlen (u_param->gvalue) + 3;
 	len = len + plen;
-	buf = (char *) realloc (buf, len);
+	buf = (char *) osip_realloc (buf, len);
 	tmp = buf;
 	tmp = tmp + strlen (tmp);
 	if (u_param->gvalue == NULL)
@@ -357,7 +357,7 @@ osip_via_to_str (const osip_via_t * via, char **dest)
   if (via->comment != NULL)
     {
       len = len + strlen (via->comment) + 4;
-      buf = (char *) realloc (buf, len);
+      buf = (char *) osip_realloc (buf, len);
       tmp = buf;
       tmp = tmp + strlen (tmp);
       sprintf (tmp, " (%s)", via->comment);
