@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -1860,7 +1860,7 @@ sdp_message_to_str (sdp_message_t * sdp, char **dest)
   char *string;
 
   *dest = NULL;
-  if (sdp->v_version == NULL)
+  if (!sdp || sdp->v_version == NULL)
     return -1;
   if (sdp->o_username == NULL ||
       sdp->o_sess_id == NULL ||
@@ -1943,7 +1943,10 @@ sdp_message_to_str (sdp_message_t * sdp, char **dest)
 	sdp_append_connection (string, size, tmp, sdp->c_connection,
 			       &next_tmp);
       if (i != 0)
-	return -1;
+	{
+	  osip_free(string);
+	  return -1;
+	}
       tmp = next_tmp;
     }
   pos = 0;
@@ -1956,7 +1959,10 @@ sdp_message_to_str (sdp_message_t * sdp, char **dest)
 
       i = sdp_append_bandwidth (string, size, tmp, header, &next_tmp);
       if (i != 0)
-	return -1;
+	{
+	  osip_free(string);
+	  return -1;
+	}
       tmp = next_tmp;
       pos++;
     }
@@ -1971,7 +1977,10 @@ sdp_message_to_str (sdp_message_t * sdp, char **dest)
 
       i = sdp_append_time_descr (string, size, tmp, header, &next_tmp);
       if (i != 0)
-	return -1;
+	{
+	  osip_free(string);
+	  return -1;
+	}
       tmp = next_tmp;
       pos++;
     }
@@ -1990,7 +1999,10 @@ sdp_message_to_str (sdp_message_t * sdp, char **dest)
 
       i = sdp_append_key (string, size, tmp, sdp->k_key, &next_tmp);
       if (i != 0)
-	return -1;
+	{
+	  osip_free(string);
+	  return -1;
+	}
       tmp = next_tmp;
     }
 
@@ -2004,7 +2016,10 @@ sdp_message_to_str (sdp_message_t * sdp, char **dest)
 
       i = sdp_append_attribute (string, size, tmp, header, &next_tmp);
       if (i != 0)
-	return -1;
+	{
+	  osip_free(string);
+	  return -1;
+	}
       tmp = next_tmp;
       pos++;
     }
@@ -2019,7 +2034,10 @@ sdp_message_to_str (sdp_message_t * sdp, char **dest)
 
       i = sdp_append_media (string, size, tmp, header, &next_tmp);
       if (i != 0)
-	return -1;
+	{
+	  osip_free(string);
+	  return -1;
+	}
       tmp = next_tmp;
       pos++;
     }
